@@ -14,15 +14,16 @@ def unlist(obj):
     return obj
 
 class FileDropArea(QtWidgets.QWidget):
-    function_selected = QtCore.pyqtSignal(dict)
-    file_selected     = QtCore.pyqtSignal(dict)
-
-    def __init__(self, log_widget: QtWidgets.QTextEdit,view_widget=None, parent=None):
+    def __init__(self,
+                 log_widget: QtWidgets.QTextEdit,
+                 view_widget=None,
+                 parent=None):
         super().__init__(parent)
-        self.allowed_extensions = DEFAULT_ALLOWED_EXTS
-        self.unallowed_extentions = DEFAULT_UNALLOWED_EXTS
-        self.exclude_dirs=DEFAULT_EXCLUDE_DIRS
-        self.exclude_file_patterns=DEFAULT_EXCLUDE_PATTERNS
+        # start with your defaults…
+        self.allowed_extensions    = DEFAULT_ALLOWED_EXTS.copy()
+        self.unallowed_extensions  = DEFAULT_UNALLOWED_EXTS.copy()
+        self.exclude_dirs          = list(DEFAULT_EXCLUDE_DIRS)
+        self.exclude_file_patterns = list(DEFAULT_EXCLUDE_PATTERNS)
         # ─── Ensure the parent accepts drops ────────────────────────────────
         self.setAcceptDrops(True)
 
@@ -108,21 +109,15 @@ class FileDropArea(QtWidgets.QWidget):
     def set_filter_config(
         self,
         *,
-        allowed_exts:        Optional[List[str]] = None,
-        unallowed_exts:      Optional[List[str]] = None,
-        exclude_dirs:        Optional[List[str]] = None,
-        exclude_file_patterns: Optional[List[str]] = None,
-    ) -> None:
-        """Replace any of the four filter‐sets with exactly what the user passed in."""
-        if allowed_exts is not None:
-            self.allowed_extensions   = {e.lower() for e in allowed_exts}
-        if unallowed_exts is not None:
-            self.unallowed_extentions = {e.lower() for e in unallowed_exts}
-        if exclude_dirs is not None:
-            self.exclude_dirs         = set(d.lower() for d in exclude_dirs)
-        if exclude_file_patterns is not None:
-            self.exclude_file_patterns = set(p.lower() for p in exclude_file_patterns)
-    # ────────────────────────────────────────────────────────────────────────
+        allowed_exts:        list[str],
+        unallowed_exts:      list[str],
+        exclude_dirs:        list[str],
+        exclude_patterns: list[str],
+    ):
+        self.allowed_extensions     = set(allowed_exts)
+        self.unallowed_extentions   = set(unallowed_exts)
+        self.exclude_dirs           = set(exclude_dirs)
+        self.exclude_patterns  = set(exclude_patterns)    # ────────────────────────────────────────────────────────────────────────
     # dragEnterEvent / dropEvent (parent still handles all drops)
     # ────────────────────────────────────────────────────────────────────────
     def dragEnterEvent(self, event: QtGui.QDragEnterEvent):
@@ -148,21 +143,18 @@ class FileDropArea(QtWidgets.QWidget):
     # ────────────────────────────────────────────────────────────────────────
     # Expand directories, exclude unwanted files
     # ────────────────────────────────────────────────────────────────────────
-    def filter_paths(self, paths: list[str]) -> list[str]:
-        
-        filtered = collect_filepaths(
-            paths,
-            exclude_dirs=self.exclude_dirs,
-            exclude_file_patterns=self.exclude_file_patterns
+    def filter_paths(self, paths: List[str]) -> List[str]:
+        filtered = collect_files(
+            roots=paths,
+            allowed_exts=       self.allowed_extensions,
+            unallowed_exts=     self.unallowed_extensions,
+            exclude_types=      None,     # or let user tweak this too
+            exclude_dirs=       self.exclude_dirs,
+            exclude_patterns=   self.exclude_file_patterns,
         )
-        self._log(f"_filtered_file_list returned {len(filtered)} path(s): {filtered!r}")
-
+        self._log(f"_filtered_file_list → {len(filtered)} files")
         if not filtered:
             self.status.setText("⚠️ No valid files detected in drop.")
-            self._log("No valid paths after filtering.")
-            return []
-
-        self._log(f"Proceeding to process {len(filtered)} file(s).")
         return filtered
     def get_contents_text(self, file_path: str, idx: int = 0, filtered_paths: list[str] = []):
         basename = os.path.basename(file_path)
@@ -429,7 +421,7 @@ class FileDropArea(QtWidgets.QWidget):
         project_files = collect_filepaths(
             [os.path.dirname(function_info['file'])],
             exclude_dirs=self.exclude_dirs,
-            exclude_file_patterns=self.exclude_file_patterns
+            exclude_patterns=self.exclude_patterns
         )
         combined_lines.append("\n\n=== Project Reach ===\n")
         for file_path in project_files:
